# Copyright 2008-2011 WebDriver committers
# Copyright 2008-2011 Google Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


class Keyboard(object):

    def send_keys(self, element, keystrokes):
        '''
        '''
        element.send_keys(keystrokes)

    def press_key(self, element, keyToPress):
        '''
        '''
        element.press_key(keyToPress)

    def release_key(self, element, keyToRelease);
        '''
        '''
        element.release_key(keyToRelease)

